@@ -12,8 +12,9 @@ log = QELogger()
 
 class Application:
     def __init__(self, component, a11y_app_name=None, desktop_file_exists=True,
-                 desktop_file_name=None, app_process_name=None, shell=None,
-                 session_type=None, session_desktop=None, logging=False):
+                 desktop_file_name="", desktop_file_path="", 
+                 app_process_name="", shell=None, session_type="", 
+                 session_desktop="", logging=False):
         """
         .. note::
 
@@ -29,6 +30,9 @@ class Application:
         :type desktop_file_exists: bool
         :param desktop_file_exists: States that desktop file of given application exists or not.
 
+        :type desktop_file_path: str
+        :param desktop_file_path: Full posix path to .desktop file of application.
+
         :type desktop_file_name: str
         :param desktop_file_name: Name of desktop file if not same as component.
 
@@ -46,6 +50,7 @@ class Application:
                 f"__init__(self, component={component}, a11y_app_name={a11y_app_name},",
                 f"desktop_file_exists={desktop_file_exists},",
                 f"desktop_file_name={desktop_file_name},",
+                f"desktop_file_path={desktop_file_path},",
                 f"app_process_name={app_process_name}, shell='shell',",
                 f"session_type={session_type}, session_desktop={session_desktop},",
                 f"logging={str(logging)})"
@@ -62,7 +67,8 @@ class Application:
         self.exit_shortcut = "<Control_L><Q>"
         self.kill = True
         self.kill_command = None
-        self.desktop_file_name = desktop_file_name if desktop_file_name else ""
+        self.desktop_file_name = desktop_file_name
+        self.desktop_file_path = desktop_file_path
         self.app_process_name = app_process_name if app_process_name else component
         self.get_desktop_file_data()
 
@@ -82,17 +88,20 @@ class Application:
             log.info(f"{self.component} get_desktop_file_data(self)")
 
         if self.desktop_file_exists: # zenity/gnome-shell do not have desktop file
-            desktop_run = run(" ".join((
-                f"rpm -qlf $(which {self.component}) |",
-                f"grep /usr/share/applications/ |",
-                f"grep .desktop |",
-                f"grep '{self.desktop_file_name}'"
-            )), verbose=True)
+            if self.desktop_file_path:
+                desktop_file = self.desktop_file_path
+            else:
+                desktop_run = run(" ".join((
+                    f"rpm -qlf $(which {self.component}) |",
+                    f"grep /usr/share/applications/ |",
+                    f"grep .desktop |",
+                    f"grep '{self.desktop_file_name}'"
+                )), verbose=True)
+                if desktop_run[1] != 0:
+                    raise Exception(f"Desktop file of application '{self.component}' was not found.")
 
-            if desktop_run[1] != 0:
-                raise Exception(f"Desktop file of application '{self.component}' was not found.")
-
-            desktop_file = desktop_run[0].strip("\n")
+                desktop_file = desktop_run[0].strip("\n")
+       
             desktop_file_config = configparser.RawConfigParser()
             desktop_file_config.read(desktop_file)
 
