@@ -2,7 +2,7 @@
 import os
 import re
 import base64
-from time import strftime, sleep, localtime
+from time import sleep
 from subprocess import Popen
 from dogtail.tree import root
 from dogtail.utils import config
@@ -209,8 +209,9 @@ class TestSandbox:
                 name,
                 a11yAppName=None,
                 desktopFileExists=True,
-                desktopFileName=None,
-                appProcessName=None):
+                desktopFileName="",
+                desktopFilePath="",
+                appProcessName=""):
         """
         This function is a wrapper over :func:`get_application` to preserve the old api name.
         This is defined as an extra function because even the method parameters were renamed to
@@ -221,13 +222,14 @@ class TestSandbox:
             log.info(" ".join((
                 f"get_app(self, name={name}, a11yAppName={a11yAppName},",
                 f"desktopFileExists={desktopFileExists}, desktopFileName={desktopFileName},",
-                f"appProcessName={appProcessName})"
+                f"desktopFilePath={desktopFilePath}, appProcessName={appProcessName})"
             )))
 
         return self.get_application(name,
                                     a11y_app_name=a11yAppName,
                                     desktop_file_exists=desktopFileExists,
                                     desktop_file_name=desktopFileName,
+                                    desktop_file_path=desktopFilePath,
                                     app_process_name=appProcessName)
 
 
@@ -235,8 +237,9 @@ class TestSandbox:
                         name,
                         a11y_app_name=None,
                         desktop_file_exists=True,
-                        desktop_file_name=None,
-                        app_process_name=None):
+                        desktop_file_name="",
+                        desktop_file_path="",
+                        app_process_name=""):
         """
         Return application to be used in test.
 
@@ -265,14 +268,18 @@ class TestSandbox:
             log.info(" ".join((
                 f"get_application(self, name={name}, a11y_app_name={a11y_app_name},",
                 f"desktop_file_exists={desktop_file_exists},",
-                f"desktop_file_name={desktop_file_name},",
+                f"desktop_file_name={desktop_file_name},", 
+                f"desktop_file_path={desktop_file_path},",
                 f"app_process_name={app_process_name})"
             )))
 
-        new_application = Application(name, a11y_app_name, desktop_file_exists,
-                                      desktop_file_name, app_process_name,
-                                      self.shell, self.session_type,
-                                      self.session_desktop, self.logging)
+        new_application = Application(name, a11y_app_name=a11y_app_name, 
+                                      desktop_file_exists=desktop_file_exists,
+                                      desktop_file_name=desktop_file_name,
+                                      desktop_file_path=desktop_file_path,
+                                      app_process_name=app_process_name,
+                                      shell=self.shell, session_type=self.session_type,
+                                      session_desktop=self.session_desktop, logging=self.logging)
 
         self.applications.append(new_application)
         self.default_application = new_application \
@@ -398,7 +405,9 @@ class TestSandbox:
         if self.logging:
             log.info("set_log_start_time(self)")
 
-        self.logging_start = strftime("%Y-%m-%d %H:%M:%S", localtime())
+        initial_cursor_output = run("journalctl --lines=0 --show-cursor").strip()
+        cursor_target = initial_cursor_output.split("cursor: ", 1)[-1]
+        self.logging_cursor = f"\"--after-cursor={cursor_target}\""
 
 
     def close_yelp(self):
@@ -477,7 +486,7 @@ class TestSandbox:
         Display clock seconds for better tracking test in video.
 
         .. note::
-            
+
             This method is called by :func:`before_scenario`.
             There was never need to have other options,
             as we want to see the seconds ticking during the test.
@@ -735,10 +744,8 @@ class TestSandbox:
             return
 
         journal_run = run(" ".join((
-            f"sudo journalctl",
-            f"--all",
-            f"--output=short-precise",
-            f"--since='{self.logging_start}'"
+            f"sudo journalctl --all",
+            f"--output=short-precise {self.logging_cursor}",
             f"> /tmp/journalctl_short.log"
         )), verbose=True)
 
