@@ -1,8 +1,8 @@
 import os
-from time import sleep, time
-from subprocess import CalledProcessError, check_output, STDOUT
 from functools import partial
-
+from subprocess import STDOUT, CalledProcessError, check_output
+from time import sleep, time
+from types import FunctionType
 
 QE_DEVELOPMENT = not os.path.isdir("/mnt/tests/")
 
@@ -124,11 +124,11 @@ def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=Fal
     if isinstance(tested, bool):
         curried_func = lambda: tested
     # or if callable(tested) and element is a list or a tuple
-    elif isinstance(tested, types.FunctionType) and \
+    elif isinstance(tested, FunctionType) and \
             isinstance(element, (tuple, list)) and params_in_list:
         curried_func = partial(tested, *element)
     # or if callable(tested) and element is not None?
-    elif isinstance(tested, types.FunctionType) and element is not None:
+    elif isinstance(tested, FunctionType) and element is not None:
         curried_func = partial(tested, element)
     else:
         curried_func = tested
